@@ -26,7 +26,6 @@
 #include "gcal-context.h"
 #include "gcal-debug.h"
 #include "gcal-log.h"
-#include "gcal-resources.h"
 #include "gcal-shell-search-provider.h"
 #include "gcal-window.h"
 
@@ -34,6 +33,7 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 #include <glib/gi18n.h>
+#include <handy.h>
 
 struct _GcalApplication
 {
@@ -446,6 +446,9 @@ gcal_application_startup (GApplication *app)
   if ((g_application_get_flags (app) & G_APPLICATION_IS_SERVICE) != 0)
     g_application_set_inactivity_timeout (app, 3 * 60 * 1000);
 
+  /*  initialize libhandy */
+  hdy_init();
+
   GCAL_EXIT;
 }
 
@@ -609,8 +612,6 @@ gcal_application_init (GcalApplication *self)
 {
   GcalManager *manager;
 
-  g_resources_register (calendar_get_resource ());
-
   g_application_add_main_option_entries (G_APPLICATION (self), gcal_application_goptions);
 
   self->context = gcal_context_new ();
