@@ -23,7 +23,7 @@
 #include "gcal-calendar-popover.h"
 #include "config.h"
 #include "gcal-debug.h"
-#include "gcal-edit-dialog.h"
+#include "gcal-event-editor-dialog.h"
 #include "gcal-event-widget.h"
 #include "gcal-context.h"
 #include "gcal-manager.h"
@@ -59,10 +59,10 @@
  * ## Edit dialog
  *
  * When an event is clicked, the views send the `event-activated`
- * signal. #GcalWindow responds to this signal opening #GcalEditDialog
+ * signal. #GcalWindow responds to this signal opening #GcalEventEditorDialog
  * with the clicked event.
  *
- * When #GcalEditDialog sends a response, #GcalWindow reacts by
+ * When #GcalEventEditorDialog sends a response, #GcalWindow reacts by
  * either propagating to gcal_manager_update_event(), or hiding
  * the delete event widgets from the views.
  *
@@ -88,7 +88,7 @@ typedef struct
 
 struct _GcalWindow
 {
-  GtkApplicationWindow parent;
+  HdyApplicationWindow parent;
 
   /* timeout ids */
   guint               notification_timeout;
@@ -115,6 +115,8 @@ struct _GcalWindow
   GtkWidget          *today_button;
   GtkWidget          *views_switcher;
 
+  GcalEventEditorDialog *event_editor;
+
   DzlSuggestionButton *search_button;
 
   /* new event popover widgets */
@@ -122,7 +124,6 @@ struct _GcalWindow
 
   /* day, week, month, year, list */
   GtkWidget          *views [6];
-  GtkWidget          *edit_dialog;
   gboolean            subscribed;
 
   GcalContext        *context;
@@ -179,7 +180,7 @@ enum
   gtk_application_set_accels_for_action (GTK_APPLICATION (app), action, tmp);\
 }
 
-G_DEFINE_TYPE (GcalWindow, gcal_window, GTK_TYPE_APPLICATION_WINDOW)
+G_DEFINE_TYPE (GcalWindow, gcal_window, HDY_TYPE_APPLICATION_WINDOW)
 
 static GParamSpec* properties[N_PROPS] = { NULL, };
 
@@ -191,7 +192,7 @@ static GParamSpec* properties[N_PROPS] = { NULL, };
 static void
 update_today_button_sensitive (GcalWindow *window)
 {
-  g_autoptr (GDateTime) now;
+  g_autoptr (GDateTime) now = NULL;
   gboolean sensitive;
 
   GCAL_ENTRY;
@@ -200,12 +201,6 @@ update_today_button_sensitive (GcalWindow *window)
 
   switch (window->active_view)
     {
-    case GCAL_WINDOW_VIEW_DAY:
-      sensitive = g_date_time_get_year (window->active_date) != g_date_time_get_year (now) ||
-                  g_date_time_get_month (window->active_date) != g_date_time_get_month (now) ||
-                  g_date_time_get_day_of_month (window->active_date) != g_date_time_get_day_of_month (now);
-      break;
-
     case GCAL_WINDOW_VIEW_WEEK:
       sensitive = g_date_time_get_year (window->active_date) != g_date_time_get_year (now) ||
                   g_date_time_get_week_of_year (window->active_date) !=  g_date_time_get_week_of_year (now);
@@ -224,8 +219,6 @@ update_today_button_sensitive (GcalWindow *window)
       sensitive = g_date_time_get_year (window->active_date) != g_date_time_get_year (now);
       break;
 
-    case GCAL_WINDOW_VIEW_LIST:
-    case GCAL_WINDOW_VIEW_SEARCH:
     default:
       sensitive = TRUE;
       break;
@@ -352,7 +345,7 @@ on_view_action_activated (GSimpleAction *action,
   else if (view == -2)
     view = --(window->active_view);
 
-  window->active_view = CLAMP (view, CLAMP(view, GCAL_WINDOW_VIEW_WEEK, GCAL_WINDOW_VIEW_MONTH), GCAL_WINDOW_VIEW_YEAR);
+  window->active_view = CLAMP (view, GCAL_WINDOW_VIEW_WEEK, GCAL_WINDOW_VIEW_YEAR);
   gtk_stack_set_visible_child (GTK_STACK (window->views_stack), window->views[window->active_view]);
 
   g_object_notify_by_pspec (G_OBJECT (user_data), properties[PROP_ACTIVE_VIEW]);
@@ -400,10 +393,8 @@ on_window_new_event_cb (GSimpleAction *action,
   default_calendar = gcal_manager_get_default_calendar (manager);
   event = gcal_event_new (default_calendar, comp, NULL);
 
-  gcal_edit_dialog_set_event_is_new (GCAL_EDIT_DIALOG (self->edit_dialog), TRUE);
-  gcal_edit_dialog_set_event (GCAL_EDIT_DIALOG (self->edit_dialog), event);
-
-  gtk_widget_show (self->edit_dialog);
+  gcal_event_editor_dialog_set_event (self->event_editor, event, TRUE);
+  gtk_widget_show (GTK_WIDGET (self->event_editor));
 }
 
 static void
@@ -469,9 +460,6 @@ view_changed (GObject    *object,
 
   g_type_class_unref (eklass);
 
-  if (view_type == GCAL_WINDOW_VIEW_SEARCH)
-    return;
-
   window->active_view = view_type;
   update_today_button_sensitive (window);
   g_object_notify_by_pspec (G_OBJECT (user_data), properties[PROP_ACTIVE_VIEW]);
@@ -621,10 +609,8 @@ edit_event (GcalQuickAddPopover *popover,
             GcalEvent           *event,
             GcalWindow          *window)
 {
-  gcal_edit_dialog_set_event_is_new (GCAL_EDIT_DIALOG (window->edit_dialog), TRUE);
-  gcal_edit_dialog_set_event (GCAL_EDIT_DIALOG (window->edit_dialog), event);
-
-  gtk_widget_show (window->edit_dialog);
+  gcal_event_editor_dialog_set_event (window->event_editor, event, TRUE);
+  gtk_widget_show (GTK_WIDGET (window->event_editor));
 }
 
 static void
@@ -644,10 +630,8 @@ create_event_detailed_cb (GcalView *view,
   default_calendar = gcal_manager_get_default_calendar (manager);
   event = gcal_event_new (default_calendar, comp, NULL);
 
-  gcal_edit_dialog_set_event_is_new (GCAL_EDIT_DIALOG (window->edit_dialog), TRUE);
-  gcal_edit_dialog_set_event (GCAL_EDIT_DIALOG (window->edit_dialog), event);
-
-  gtk_widget_show (window->edit_dialog);
+  gcal_event_editor_dialog_set_event (window->event_editor, event, TRUE);
+  gtk_widget_show (GTK_WIDGET (window->event_editor));
 
   g_clear_object (&comp);
 }
@@ -661,98 +645,49 @@ event_activated (GcalView        *view,
   GcalEvent *event;
 
   event = gcal_event_widget_get_event (event_widget);
-  gcal_edit_dialog_set_event_is_new (GCAL_EDIT_DIALOG (window->edit_dialog), FALSE);
-  gcal_edit_dialog_set_event (GCAL_EDIT_DIALOG (window->edit_dialog), event);
-
-  gtk_widget_show (window->edit_dialog);
+  gcal_event_editor_dialog_set_event (window->event_editor, event, FALSE);
+  gtk_widget_show (GTK_WIDGET (window->event_editor));
 }
 
 static void
-edit_dialog_closed (GtkDialog *dialog,
-                    gint       response,
-                    gpointer   user_data)
+on_event_editor_dialog_remove_event_cb (GcalEventEditorDialog *edit_dialog,
+                                        GcalEvent             *event,
+                                        GcalRecurrenceModType  modifier,
+                                        GcalWindow            *self)
 {
-  GcalRecurrenceModType mod;
-  GcalCalendar *calendar;
+  g_autoptr (GList) widgets = NULL;
   GcalManager *manager;
-  GcalWindow *window;
-  GcalEditDialog *edit_dialog;
-  GcalEvent *event;
   GcalView *view;
-  GList *widgets;
 
   GCAL_ENTRY;
 
-  window = GCAL_WINDOW (user_data);
-  manager = gcal_context_get_manager (window->context);
-  edit_dialog = GCAL_EDIT_DIALOG (dialog);
-  event = gcal_edit_dialog_get_event (edit_dialog);
-  view = GCAL_VIEW (window->views[window->active_view]);
-  mod = GCAL_RECURRENCE_MOD_THIS_ONLY;
-  calendar = gcal_event_get_calendar (event);
+  manager = gcal_context_get_manager (self->context);
+  view = GCAL_VIEW (self->views[self->active_view]);
 
-  if (!gcal_edit_dialog_get_recurrence_changed (edit_dialog) &&
-      gcal_event_has_recurrence (event) &&
-      (response != GCAL_RESPONSE_CREATE_EVENT &&
-       response != GTK_RESPONSE_CANCEL &&
-       response != GTK_RESPONSE_DELETE_EVENT &&
-       gcal_event_has_recurrence (event) &&
-       !ask_recurrence_modification_type (GTK_WIDGET (dialog), &mod, calendar)))
+  if (self->event_to_delete)
     {
-      return;
+      gcal_manager_remove_event (manager, self->event_to_delete, self->event_to_delete_mod);
+      g_clear_object (&self->event_to_delete);
+
+      create_notification (self, _("Another event deleted"), _("Undo"));
+    }
+  else
+    {
+      create_notification (self, _("Event deleted"), _("Undo"));
     }
 
+  gtk_revealer_set_reveal_child (GTK_REVEALER (self->notification), TRUE);
 
-  switch (response)
-    {
-    case GCAL_RESPONSE_CREATE_EVENT:
-      gcal_manager_create_event (manager, event);
-      break;
+  g_clear_handle_id (&self->notification_timeout, g_source_remove);
+  self->notification_timeout = g_timeout_add_seconds (5, hide_notification_scheduled, self);
 
-    case GCAL_RESPONSE_SAVE_EVENT:
-      gcal_manager_update_event (manager, event, mod);
-      break;
+  g_set_object (&self->event_to_delete, event);
+  self->event_to_delete_mod = modifier;
 
-    case GCAL_RESPONSE_DELETE_EVENT:
-      if (window->event_to_delete != NULL)
-        {
-          gcal_manager_remove_event (manager, window->event_to_delete, window->event_to_delete_mod);
-          g_clear_object (&window->event_to_delete);
+  /* hide widget of the event */
+  widgets = gcal_view_get_children_by_uuid (view, modifier, gcal_event_get_uid (event));
 
-          create_notification (GCAL_WINDOW (user_data), _("Another event deleted"), _("Undo"));
-        }
-      else
-        {
-          create_notification (GCAL_WINDOW (user_data), _("Event deleted"), _("Undo"));
-        }
-
-      gtk_revealer_set_reveal_child (GTK_REVEALER (window->notification), TRUE);
-
-      if (window->notification_timeout != 0)
-        g_source_remove (window->notification_timeout);
-
-      window->notification_timeout = g_timeout_add_seconds (5, hide_notification_scheduled, user_data);
-
-      g_set_object (&window->event_to_delete, event);
-
-      window->event_to_delete_mod = mod;
-
-      /* hide widget of the event */
-      widgets = gcal_view_get_children_by_uuid (view, mod, gcal_event_get_uid (event));
-
-      g_list_foreach (widgets, (GFunc) gtk_widget_hide, NULL);
-      g_list_free (widgets);
-      break;
-
-    case GTK_RESPONSE_CANCEL:
-    default:
-      break;
-
-    }
-
-  gtk_widget_hide (GTK_WIDGET (dialog));
-
-  gcal_edit_dialog_set_event (edit_dialog, NULL);
+  g_list_foreach (widgets, (GFunc) gtk_widget_hide, NULL);
 
   GCAL_EXIT;
 }
@@ -891,7 +826,7 @@ gcal_window_constructed (GObject *object)
   g_object_bind_property (self, "context", self->week_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->month_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->year_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
-  g_object_bind_property (self, "context", self->edit_dialog, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+  g_object_bind_property (self, "context", self->event_editor, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->quick_add_popover, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->search_button, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
 
@@ -1020,7 +955,7 @@ gcal_window_class_init (GcalWindowClass *klass)
 
   g_type_ensure (GCAL_TYPE_CALENDAR_MANAGEMENT_DIALOG);
   g_type_ensure (GCAL_TYPE_CALENDAR_POPOVER);
-  g_type_ensure (GCAL_TYPE_EDIT_DIALOG);
+  g_type_ensure (GCAL_TYPE_EVENT_EDITOR_DIALOG);
   g_type_ensure (GCAL_TYPE_MANAGER);
   g_type_ensure (GCAL_TYPE_MONTH_VIEW);
   g_type_ensure (GCAL_TYPE_QUICK_ADD_POPOVER);
@@ -1073,7 +1008,7 @@ gcal_window_class_init (GcalWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, back_button);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, calendars_button);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, calendar_popover);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, edit_dialog);
+  gtk_widget_class_bind_template_child (widget_class, GcalWindow, event_editor);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, forward_button);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, header_bar);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, main_box);
@@ -1113,7 +1048,7 @@ gcal_window_class_init (GcalWindowClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, window_state_changed);
 
   /* Edit dialog related */
-  gtk_widget_class_bind_template_callback (widget_class, edit_dialog_closed);
+  gtk_widget_class_bind_template_callback (widget_class, on_event_editor_dialog_remove_event_cb);
 }
 
 static void
@@ -1169,9 +1104,9 @@ gcal_window_init (GcalWindow *self)
   app = g_application_get_default ();
   gcal_window_add_accelerator (app, "win.change-view(-1)",   "<Ctrl>Page_Down");
   gcal_window_add_accelerator (app, "win.change-view(-2)",   "<Ctrl>Page_Up");
-  gcal_window_add_accelerator (app, "win.change-view(1)",    "<Ctrl>1")
-  gcal_window_add_accelerator (app, "win.change-view(2)",    "<Ctrl>2");
-  gcal_window_add_accelerator (app, "win.change-view(3)",    "<Ctrl>3");
+  gcal_window_add_accelerator (app, "win.change-view(0)",    "<Ctrl>1");
+  gcal_window_add_accelerator (app, "win.change-view(1)",    "<Ctrl>2");
+  gcal_window_add_accelerator (app, "win.change-view(2)",    "<Ctrl>3");
   gcal_window_add_accelerator (app, "app.quit", "<Ctrl>q");
   gcal_window_add_accelerator (app, "win.new-event", "<Ctrl>n");
 }
